Improve this doc

# Error: ngRepeat:iidexp
Invalid Identifier

    '_item_' in '_item_ in _collection_' should be an identifier or '(_key_, _value_)' expression, but got '{0}'.

## Description

Occurs when there is an error in the identifier part of ngRepeat's expression.

To resolve, use either a valid identifier or a tuple (key, value) where both key and value are valid identifiers.

Examples of invalid syntax:

    <div ng-repeat="33 in users"></div>
    <div ng-repeat="someFn() in users"></div>
    <div ng-repeat="some user in users"></div>

Examples of valid syntax:

    <div ng-repeat="user in users"></div>
    <div ng-repeat="(id, user) in userMap"></div>

Please consult the api documentation of ngRepeat to learn more about valid syntax.